@@ -1,18 +1,19 @@
 #' R + mermaid.js
 #'
-#' @description Make diagrams in R using \href{https://github.com/mdaines/viz.js}{viz.js} or
+#' @description Make diagrams in R using
+#' \href{https://github.com/mdaines/viz.js}{viz.js} or
 #' \href{https://github.com/knsv/mermaid}{mermaid.js} with infrastructure
 #' provided by \href{http://www.htmlwidgets.org/}{htmlwidgets}.
 #'
 #' @param diagram diagram in \code{graphviz} or \code{mermaid} format or a
 #' file (as a connection or file name) containing a diagram specification. The
-#' recommended filename extensions are '.gv' and '.mmd' for the Graphviz and the
-#' mermaid diagram specifications, respectively. If no diagram is provided,
-#' \code{diagram = ""} then the function will assume that
+#' recommended filename extensions are \code{.gv} and \code{.mmd} for the
+#' Graphviz and the mermaid diagram specifications, respectively. If no diagram
+#' is provided (\code{diagram = ""}) then the function will assume that
 #' a diagram will be provided by \code{\link[htmltools]{tags}} and
 #' \code{DiagrammeR} is just being used for dependency injection.
-#' @param type string - either "mermaid" (default) or "grViz" indicating
-#' the type of diagram spec and the desired parser/renderer
+#' @param type string - either \code{mermaid} (default) or \code{grViz}
+#' indicating the type of diagram spec and the desired parser/renderer
 #' @param ... any other parameters to pass to \code{grViz} or \code{mermaid}
 #' @return An object of class \code{htmlwidget} that will
 #' intelligently print itself into HTML in a variety of contexts
@@ -129,25 +130,42 @@ DiagrammeR <- function(diagram = "", type = "mermaid", ...) {
   } else if( grepl( x = type, pattern = "[g,G]?[r,R]?.*[v,V][i].*" )  ) {
     grViz( diagram, ... )
   } else {
-    stop ( "type should equal 'mermaid' or 'grViz' ")
+    stop("The type should be 'mermaid' or 'grViz'.")
   }
 }
 
 #' Widget output function for use in Shiny
 #' @param outputId output variable to read from
-#' @param width a valid CSS unit for the width or a number, which will be coerced to a string and have "px" appended.
-#' @param height a valid CSS unit for the height or a number, which will be coerced to a string and have "px" appended.
+#' @param width a valid CSS unit for the width or a number, which will be
+#' coerced to a string and have \code{px} appended.
+#' @param height a valid CSS unit for the height or a number, which will be
+#' coerced to a string and have \code{px} appended.
 #' @export
-DiagrammeROutput <- function(outputId, width = '100%', height = '400px'){
-  shinyWidgetOutput(outputId, 'DiagrammeR', width, height, package = 'DiagrammeR')
+DiagrammeROutput <- function(outputId,
+                             width = '100%',
+                             height = '400px'){
+
+  htmlwidgets::shinyWidgetOutput(outputId,
+                                 'DiagrammeR',
+                                 width,
+                                 height,
+                                 package = 'DiagrammeR')
 }
 
 #' Widget render function for use in Shiny
 #' @param expr an expression that generates a DiagrammeR graph
 #' @param env the environment in which to evaluate expr.
-#' @param quoted is expr a quoted expression (with quote())? This is useful if you want to save an expression in a variable.
+#' @param quoted is expr a quoted expression (with quote())? This is useful
+#' if you want to save an expression in a variable.
 #' @export
-renderDiagrammeR <- function(expr, env = parent.frame(), quoted = FALSE) {
+renderDiagrammeR <- function(expr,
+                             env = parent.frame(),
+                             quoted = FALSE){
+
   if (!quoted) expr <- substitute(expr)
-  shinyRenderWidget(expr, DiagrammeROutput, env, quoted = TRUE)
+
+  htmlwidgets::shinyRenderWidget(expr,
+                                 DiagrammeROutput,
+                                 env,
+                                 quoted = TRUE)
 }
