@@ -18,7 +18,6 @@
 #' edges <-
 #'   create_edges(from = sample(LETTERS, replace = TRUE),
 #'                to = sample(LETTERS, replace = TRUE),
-#'                label = "edge",
 #'                rel = "letter_to_letter")
 #'
 #' graph <-
@@ -29,48 +28,36 @@
 #'                               "shape = circle"))
 #'
 #' edge_info(graph)
-#' #>    from   to              rel label
-#' #> 1     A    Z letter_to_letter  edge
-#' #> 2     H    U letter_to_letter  edge
-#' #> 3     W    O letter_to_letter  edge
-#' #> 4     U    K letter_to_letter  edge
-#' #> 5     I    V letter_to_letter  edge
-#' #>..   ...  ...              ...   ...
+#' #>    from   to              rel
+#' #> 1     A    Z letter_to_letter
+#' #> 2     H    U letter_to_letter
+#' #> 3     W    O letter_to_letter
+#' #> 4     U    K letter_to_letter
+#' #> 5     I    V letter_to_letter
+#' #>..   ...  ...              ...
 #' }
 #' @export edge_info
 
 edge_info <- function(graph){
 
-  #   if ("edge_from" %in% colnames(graph$edges_df)){
-  #     edge_from <- graph$edges_df$edge_from
-  #   }
-
   if ("from" %in% colnames(graph$edges_df)){
     edge_from <- graph$edges_df$from
   }
 
-  #   if ("edge_to" %in% colnames(graph$edges_df)){
-  #     edge_to <- graph$edges_df$edge_to
-  #   }
-
   if ("to" %in% colnames(graph$edges_df)){
     edge_to <- graph$edges_df$to
   }
 
-  if ("label" %in% colnames(graph$edges_df)){
-    label <- graph$edges_df$label
-  }
-
   if ("rel" %in% colnames(graph$edges_df)){
-    rel <- graph$edges_df$rel
+    relationship <- graph$edges_df$rel
   }
 
   # For graphs with no edges, create an 'edge_properties' data frame
   # that doesn't need to consider any edge information
   if (is.null(graph$edges_df)){
 
-    edge_properties <- as.data.frame(mat.or.vec(nr = 0, nc = 4))
-    colnames(edge_properties) <- c("from", "to", "rel", "label")
+    edge_properties <- as.data.frame(mat.or.vec(nr = 0, nc = 3))
+    colnames(edge_properties) <- c("from", "to", "rel")
 
     return(edge_properties)
   }
@@ -82,23 +69,20 @@ edge_info <- function(graph){
     for (i in 1:length(edge_from)){
 
       if (i == 1){
-        edge_properties <- as.data.frame(mat.or.vec(nr = 0, nc = 4))
-        colnames(edge_properties) <- c("from", "to", "rel", "label")
+        edge_properties <- as.data.frame(mat.or.vec(nr = 0, nc = 3))
+        colnames(edge_properties) <- c("from", "to", "rel")
       }
 
       # Collect information into the 'edge_properties' data frame
       edge_properties[i, 1] <- edge_from[i]
+
       edge_properties[i, 2] <- edge_to[i]
+
       edge_properties[i, 3] <-
-        ifelse(exists("rel"),
-               rel[which((edge_from %in% edge_from[i]) &
+        ifelse(exists("relationship"),
+               relationship[which((edge_from %in% edge_from[i]) &
                            (edge_to %in% edge_to[i]))],
                rep(NA, length(edge_from)))
-      edge_properties[i, 4] <-
-        ifelse(exists("label"),
-               label[which((edge_from %in% edge_from[i]) &
-                             (edge_to %in% edge_to[i]))],
-               rep(NA, length(edge_from)))
     }
 
     return(edge_properties)
